==> AsposeCellsCloud-CellsApi-25.9.tar.gz: AsposeCellsCloud-CellsApi-25.9/docs/model/ComboBox.md <==
# AsposeCellsCloud::Object::ComboBox 

## Load the model package
```perl
use AsposeCellsCloud::Object::ComboBox;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**DropDownLines** | **int** | Gets or sets the number of list lines displayed in the drop-down portion of a combo box. |
**InputRange** | **string** | Property Summary: Contains a public string property named "InputRange" with both get and set accessors. |
**SelectedCell** | **LinkElement** | Gets the selected cell in the input range of the combo box. |
**SelectedIndex** | **int** | Gets or sets the index number of the currently selected item in a list box or combo box.                        Zero-based. |
**SelectedValue** | **string** | Gets the selected value of the combox box. |
**Shadow** | **boolean** | Indicates whether the combobox has 3-D shading. |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/ComboBox.md <==
# AsposeCellsCloud::Object::ComboBox 

## Load the model package
```perl
use AsposeCellsCloud::Object::ComboBox;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**DropDownLines** | **int** | Gets or sets the number of list lines displayed in the drop-down portion of a combo box. |
**InputRange** | **string** | Property Summary: Contains a public string property named "InputRange" with both get and set accessors. |
**SelectedCell** | **LinkElement** | Gets the selected cell in the input range of the combo box. |
**SelectedIndex** | **int** | Gets or sets the index number of the currently selected item in a list box or combo box.                        Zero-based. |
**SelectedValue** | **string** | Gets the selected value of the combox box. |
**Shadow** | **boolean** | Indicates whether the combobox has 3-D shading. |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
